summaryrefslogtreecommitdiffstats
path: root/sbin/tunefs
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
committertrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
commit896f3841bf047ca93766900f8cd8c5852e6a9245 (patch)
tree0adfec655f17ae1258112946fa8d7d72c9c75f76 /sbin/tunefs
parent0c40c9d08e198e96b30b9b27d5caea7fce0f7118 (diff)
downloadFreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.zip
FreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.tar.gz
more file system > filesystem
Diffstat (limited to 'sbin/tunefs')
-rw-r--r--sbin/tunefs/tunefs.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sbin/tunefs/tunefs.c b/sbin/tunefs/tunefs.c
index 39ca9d0..b40c8cb 100644
--- a/sbin/tunefs/tunefs.c
+++ b/sbin/tunefs/tunefs.c
@@ -46,7 +46,7 @@ static const char rcsid[] =
#endif /* not lint */
/*
* tunefs: change layout parameters to an existing file system.
*/
#include <sys/param.h>
#include <sys/mount.h>
@@ -219,7 +219,7 @@ again:
err(1, "%s", special);
}
if (fs == NULL && (st.st_mode & S_IFMT) == S_IFDIR)
- errx(10, "%s: unknown file system", special);
+ errx(10, "%s: unknown filesystem", special);
getsb(&sblock, special);
if (pflag) {
@@ -343,7 +343,7 @@ again:
if (mount("ufs", fs->fs_file,
stfs.f_flags | MNT_UPDATE | MNT_RELOAD, &args) < 0)
err(9, "%s: reload", special);
- warnx("file system reloaded");
+ warnx("filesystem reloaded");
}
exit(0);
}
@@ -46,7 +46,7 @@ static const char rcsid[] =
#endif /* not lint */
/*
- * tunefs: change layout parameters to an existing file system.
+ * tunefs: change layout parameters to an existing filesystem.
*/
#include <sys/param.h>
OpenPOWER on IntegriCloud